#[macro_use]
extern crate handlebars;
use handlebars::{Context, Output, Handlebars, Helper, RenderContext, RenderError};

#[macro_use]
extern crate serde_json;

fn json_format_helper(helper: &Helper, _: &Handlebars, _: &Context, _: &mut RenderContext, out: &mut Output) -> Result<(), RenderError> {
    let param = helper.param(0).ok_or(RenderError::new("Param 0 is required for format helper.",),)?;
    out.write(&param.value().to_string())?;
    Ok(())
}

handlebars_helper!(eqs: |x: str, y: str| x == y);

pub fn register(handle: &mut Handlebars) {
    handle.register_helper("JSONstringify", Box::new(json_format_helper));
    handle.register_helper("eqs", Box::new(eqs));
}

#[cfg(test)]
mod tests {
    use Handlebars;
    use register;

    #[test]
    fn test_stringify() {
        let mut handlebars = Handlebars::new();
        register(&mut handlebars);

        println!("{:?}", handlebars.render_template("{{JSONstringify foo}}", &json!({
            "foo": {
                "bar": 1,
                "baz": 2
            }
        })).unwrap());
    }

    #[test]
    fn test_eqs () {
        let mut handlebars = Handlebars::new();
        register(&mut handlebars);

        assert_eq!(
            handlebars.render_template("{{#if (eqs page \"login\")}}login{{/if}}", &json!({
                "page": "login"
            })).unwrap(),
            "login"
        );
    }
}
